//! Errors of the crate.

mod capacity_error;
pub use capacity_error::*;

mod insert_error;
pub use insert_error::*;

mod index_error;
pub use index_error::*;
